#
# spec file for package open-vm-tools
#
# Copyright (c) 2012 Red Hat Inc.
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Dominique Leuenberger, Amsterdam, Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugzilla.redhat.com

# exclude AMD PCnet32 LANCE pci.id from Supplements list [bnc#397554]
%define __find_supplements sh -c '/usr/lib/rpm/find-supplements %{name} | grep -v pci:v00001022d00002000'

# Modules that have to be build up to version 12.1 (Last checked on 2011-09-21 with kernel 3.1-rc6)
%define vm_modules vmblock vmhgfs vmsync vmxnet vmci vsock

# X modules are lower prio upstream and once in a while fail. Offer an easy way to enable/disable them.
%define with_X 0

Name:           open-vm-tools
Version:        8.8.0
Release:        7%{?dist}
%define         svn_rev 471268
License:        BSD and GPLv2 and LGPLv2+
Summary:        Open Virtual Machine Tools
Url:            http://open-vm-tools.sourceforge.net/
Group:          Applications/Emulators
Source:         http://sourceforge.net/projects/open-vm-tools/files/open-vm-tools/stable-8.8.x/%{name}-%{version}-%{svn_rev}.tar.gz
Source1:        vmtoolsd
# PATCH-FIX-UPSTREAM open-vm-tools-vmxnet+kernel-3.0.patch idoenmez@suse.de -- Fix compilation with kernel 3.0
Patch0:         open-vm-tools-vmxnet+kernel-3.0.patch
BuildRequires:  gettext
BuildRequires:  gcc-c++
BuildRequires:  libdnet-devel
BuildRequires:  glib2
BuildRequires:  glib2-devel
BuildRequires:  module-init-tools
BuildRequires:  procps
BuildRequires:  pam-devel
ExclusiveArch:  %ix86 x86_64
BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires:        open-vm-toolsd = %{version}-%{release}

%description
Open Virtual Machine Tools (open-vm-tools) are the open source
implementation of VMware Tools. They are a set of guest operating
system virtualization components that enhance performance and user
experience of virtual machines. As virtualization technology rapidly
becomes mainstream, each virtualization solution provider implements
their own set of tools and utilities to supplement the guest virtual
machine. However, most of the implementations are proprietary and are
tied to a specific virtualization platform.

With the Open Virtual Machine Tools project, we are hoping to solve
this and other related problems. The tools are currently composed of
kernel modules for Linux and user-space programs for all VMware
supported Unix-like guest operating systems. They provide several
useful functions like:

* File transfer between a host and guest

* Improved memory management and network performance under
   virtualization

* General mechanisms and protocols for communication between host and
guests and from guest to guest

NOTE: Since the upstream contains out-of-tree kernel modules, this package
only builds the upstream parts that can be used without the kernel modules

%package        -n open-vm-toolsd
License:        BSD and GPLv2 and LGPLv2+
Summary:        Utilities and daemon for Open Virtual Machine Tools
Group:          Applications/Emulators
Requires:       open-vm-tools-libs = %{version}-%{release}
%description    -n open-vm-toolsd
The vmtoolsd service and various command line utilities from
%{name}. Install these in your virtual machine to enable a number of
features that depend on special communications between your virtual machine
and hte host.

%package        libs
License:        BSD and GPLv2 and LGPLv2+
Summary:        Libraries for Open Virtual Machine Tools
Group:          System/Libraries
%description    libs
The libraries for %{name}.

%package        devel
License:        BSD and GPLv2 and LGPLv2+
Summary:        Development files for %{name}
Group:          Development
Requires:       open-vm-tools-libs = %{version}-%{release}
%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n %{name}-%{version}-%{svn_rev}
%patch0 -p0
chmod -x AUTHORS COPYING ChangeLog NEWS README
# fix for an rpmlint warning regarding wrong line feeds
sed -i -e "s/\r//" README

%build
# disable warning unused-but-set-variable which will raise error because of -Werror
export CFLAGS="%{optflags} -Wno-unused-but-set-variable"
%configure \
    --disable-unity \
    --without-kernel-modules \
    --without-root-privileges \
    --without-procps \
    --without-x \
    --without-gtk2 \
    --without-gtkmm \
    --without-icu \
    --disable-dependency-tracking \
    --disable-static

# Hardcoded RPATH is not allowed.
# See http://fedoraproject.org/wiki/Packaging:Guidelines#Beware_of_Rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make

%install
rm -rf %{buildroot}

make DESTDIR=%{buildroot} install
chmod -x %{buildroot}/%{_sysconfdir}/pam.d/vmtoolsd
# Clean up the *.la files make install put all around
find %{buildroot} -name '*.la' -delete -print

# install the vmtoolsd init script
install -D -m 0755 %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/vmtoolsd

# Remove unsupported files; mostly unsupported sicne we do not build
# the kernel modules
# No vmhgfs module
rm %{buildroot}/sbin/mount.vmhgfs
rm %{buildroot}%{_sbindir}/mount.vmhgfs
rm %{buildroot}%{_bindir}/vmware-hgfsclient
rm %{buildroot}%{_libdir}/libhgfs.*
# No hgfs kmod
rm %{buildroot}%{_libdir}/open-vm-tools/plugins/common/libvix.so
rm %{buildroot}%{_libdir}/open-vm-tools/plugins/common/libhgfsServer.so
# No vmsync module
rm %{buildroot}%{_libdir}/open-vm-tools/plugins/vmsvc/libvmbackup.so

# the script installs some binaries into /usr/share/open-vm-tools which are
# just some tests.  So we drop them for the moment. Upstream has been
# informed about this.
rm -r %{buildroot}%{_datadir}/%{name}

%preun
if [ $1 -eq 0 ] ; then
  /sbin/service vmtoolsd stop >/dev/null 2>&1
  /sbin/chkconfig --del vmtoolsd
fi

%postun
if [ "$1" -ge "1" ] ; then
  /sbin/service vmtoolsd condrestart >/dev/null 2>&1 || :
fi

%post libs -p /sbin/ldconfig

%post -n open-vm-toolsd
/sbin/chkconfig --add vmtoolsd
if [ "$1" -ge "1" ] ; then
  /sbin/service vmtoolsd restart >/dev/null 2>&1 || :
fi

%postun libs -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
# Intentionally empty

%files -n open-vm-toolsd
%defattr(-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS README
%{_bindir}/vmtoolsd
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins/common
%dir %{_libdir}/%{name}/plugins/vmsvc
%{_libdir}/%{name}/plugins/vmsvc/libguestInfo.so
%{_libdir}/%{name}/plugins/vmsvc/libpowerOps.so
%{_libdir}/%{name}/plugins/vmsvc/libtimeSync.so
%{_bindir}/vmware-checkvm
%{_bindir}/vmware-rpctool
%{_bindir}/vmware-toolbox-cmd
%{_bindir}/vmware-xferlogs
%config(noreplace) %{_sysconfdir}/pam.d/vmtoolsd
%{_sysconfdir}/vmware-tools
%{_sysconfdir}/init.d/vmtoolsd
%exclude %{_libdir}/*.so

%files libs
%defattr(-, root, root)
%{_libdir}/libvmtools.so.*
%{_libdir}/libguestlib.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/vmGuestLib
%{_libdir}/*.so
%{_libdir}/pkgconfig/vmguestlib.pc

%changelog
* Tue Mar 20 2012 Michal Fojtik <mfojtik@redhat.com> - 8.8.0-7%{dist}
- Added missing require (#802877)

* Mon Mar 19 2012 Michal Fojtik <mfojtik@redhat.com> - 8.8.0-6%{dist}
- Fix for wrong dist tag (#802877)

* Mon Mar 19 2012 Michal Fojtik <mfojtik@redhat.com> - 8.8.0-5%{dist}
- Fixed dist tag

* Wed Feb 13 2012 Michal Fojtik <mfojtik@redhat.com> - 8.8.0-4%{dist}
- Fixed service autostarting

* Wed Feb 13 2012 Michal Fojtik <mfojtik@redhat.com> - 8.8.0-3%{dist}
- Added Red Hat copyright to list
- Added service autostart after install

* Wed Feb  8 2012 David Lutterkort <lutter@redhat.com> - 8.8.0-2%{dist}
- Bump to get i386 and x86_64 builds in brew (move to cf-tools-1.0-rhel6 tag)

* Wed Feb  8 2012 David Lutterkort <lutter@redhat.com> - 8.8.0-1%{dist}
- remove libvix plugin since it requires libhgfs, which we don't use

* Sat Jan 28 2012 David Lutterkort <lutter@redhat.com> - 8.8.0-0%{dist}.2
- Removed unused passages from specfile
- Pruned changelog (removed all but the last entry from SuSe)
- Remove autotools and pcre-devel from BR
- Rename subpackages
- Remove anything related to vmhgfs and vmsync

* Fri Jan 27 2012 Michal Fojtik <mfojtik@redhat.com> - 8.8.0-0%{dist}.1
- Updated spec file and init script to work under RHEL6

* Wed Sep 21 2011 Dominique Leuenberger <dimstar@opensuse.org> - 8.8.0-0%{dist}.0
- Update to version 8.8.0 (Stable series):
  + This release of open-vm-tools matches the VMware Tools package
    released with Workstation 8.0 and Fusion 4.0.
    It's targeted at desktop users who want the latest features in
    (VMware's) Unity, HGFS and drag & drop support.
- Add open-vm-tools-vmxnet+kernel-3.0.patch: HAVE_NETDEV_PRIV is
  gone in kernel 3.0 and netdev_priv is in kernel since 2.6.6.
- use set_permissions instead of run_permissions on 11.4+
